@@ -19,13 +19,14 @@ var STYLE_BOX = {
   padding: '0.625em',
   background: '#f7f7f9',
   border: '1px solid #e1e1e8',
-  margin: '0.3em',
   cursor: 'pointer',
   position: 'relative',
   boxShadow: '0 1px 6px 0 rgba(0, 0, 0, 0.11), 0 1px 4px 0 rgba(0, 0, 0, 0.11)',
   borderRadius: '2px',
   transition: 'all .2s ease-in-out',
-  WebkitTransition: 'all .2s ease-in-out'
+  WebkitTransition: 'all .2s ease-in-out',
+  alignSelf: 'center',
+  justifySelf: 'center'
 };
 
 var STYLE_BOX_HOVER = _extends({}, STYLE_BOX, {
@@ -60,7 +61,7 @@ var STYLE_NEXT_HOVER = {
 var CONTAINER_DIV = {
   background: SharedStyle.COLORS.white,
   marginBottom: '5px',
-  border: 'solid 1px #e6e6e6',
+  border: 'solid 1px #EEE',
   width: '100%',
   height: '100%',
   display: 'flex',
