@@ -1,4 +1,5 @@
-import React, {PropTypes} from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 import Layer from './layer';
 import Guides from './guides/guides';
 export default function Scene({scene, catalog}) {
